<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendarwindow.cpp" line="203"/>
        <source>First Day of Week</source>
        <translation>週はじめ</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Deepin Calendar</source>
        <translation>Deepin カレンダー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Calendar is a date tool.</source>
        <translation>カレンダーは日時ツールです。</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="24"/>
        <source>Today</source>
        <translation>今日</translation>
    </message>
</context>
</TS>